<?php
 
class SimpleImage {
 
   private $image;
   private $image_type;
 
   public function load($filename) {
 
      $image_info = getimagesize($filename);
      $this->image_type = $image_info[2];
      if( $this->image_type == IMAGETYPE_JPEG ) {
 
         $this->image = imagecreatefromjpeg($filename);
      } elseif( $this->image_type == IMAGETYPE_GIF ) {
 
         $this->image = imagecreatefromgif($filename);
      } elseif( $this->image_type == IMAGETYPE_PNG ) {
 
         $this->image = imagecreatefrompng($filename);
      }
   }
   public function save($filename, $image_type=IMAGETYPE_JPEG, $compression=75, $permissions=null) {
 
      if( $image_type == IMAGETYPE_JPEG ) {
         imagejpeg($this->image,$filename,$compression);
      } elseif( $image_type == IMAGETYPE_GIF ) {
 
         imagegif($this->image,$filename);
      } elseif( $image_type == IMAGETYPE_PNG ) {
 
         imagepng($this->image,$filename);
      }
      if( $permissions != null) {
 
         chmod($filename,$permissions);
      }
   }
   public function output($image_type=IMAGETYPE_JPEG) {
 
      if( $image_type == IMAGETYPE_JPEG ) {
         imagejpeg($this->image);
      } elseif( $image_type == IMAGETYPE_GIF ) {
 
         imagegif($this->image);
      } elseif( $image_type == IMAGETYPE_PNG ) {
 
         imagepng($this->image);
      }
   }
   public function getWidth() {
 
      return imagesx($this->image);
   }
   public function getHeight() {
 
      return imagesy($this->image);
   }
   
   public function getType(){
      return $this->image_type; 
   }
   
   public function resizeToHeight($height) {
 
      $ratio = $height / $this->getHeight();
      $width = $this->getWidth() * $ratio;
      $this->resize($width,$height);
   }
 
   public function resizeToWidth($width) {
      $ratio = $width / $this->getWidth();
      $height = $this->getheight() * $ratio;
      $this->resize($width,$height);
   }
 
   public function scale($scale) {
      $width = $this->getWidth() * $scale/100;
      $height = $this->getheight() * $scale/100;
      $this->resize($width,$height);
   }
 
   public function resize($width,$height) {
      $new_image = imagecreatetruecolor($width, $height);
      imagecopyresampled($new_image, $this->image, 0, 0, 0, 0, $width, $height, $this->getWidth(), $this->getHeight());
      $this->image = $new_image;
   }     
   
    public function cropCenter($w,$h){
        $new_image = imagecreatetruecolor($w, $h);      
        if ($w<$h) {
            $this->resizeToWidth($w);  
            imagecopy($new_image,$this->image,0,0,0,round(($this->getHeight()-$h)/2),$w,$h);  
        }
        else {
            $this->resizeToHeight($h);
            imagecopy($new_image,$this->image,0,0,round(($this->getWidth()-$w)/2),0,$w,$h);
        }
        $this->image = $new_image;
    }
    
    public function checkMin($min_w,$min_h){
        $delta_w=$min_w-$this->getWidth();
        $delta_h=$min_h-$this->getHeight();
        
        if ($delta_h>0 || $delta_w>0){
            if ($delta_h>$delta_w) $this->resizeToHeight($min_h);
            else $this->resizeToWidth($min_w);
        }
    } 
    
    public function checkMax($max_w,$max_h){
        $delta_w=$this->getWidth()-$max_w;
        $delta_h=$this->getHeight()-$max_h;
        
        if ($delta_h>0 || $delta_w>0){
            if ($delta_h>$delta_w) $this->resizeToHeight($max_h);
            else $this->resizeToWidth($max_w);
        }
    }
 
}
?>